@@ -2,6 +2,7 @@ import logging
 import os
 import shutil
 import typing
+import more_itertools
 from pathlib import Path
 
 from ._type_hint_helpers import PathString
@@ -21,15 +22,15 @@ def get_subcollections(collection):
 
             if attr:=getattr(page, subcollection, None):
                 if isinstance(attr, list):
-                    map(
-                            lambda x: subcollection_set.add((subcollection, x)),
-                            attr)
+                    for subattr in attr:
+                        subcollection_set.add((subcollection, subattr))
 
                 else:
                     subcollection_set.add((subcollection, attr))
 
     return subcollection_set
 
+
 class Site:
     """
     The site stores your pages and collections to be rendered.
@@ -65,6 +66,7 @@ class Site:
     """
     routes: typing.List[str] = []
     collections = {}
+    subcollections = {}
     output_path: Path = Path("output")
     static_path: Path = Path("static")
     SITE_TITLE: str = "Untitled Site"
@@ -143,7 +145,15 @@ class Site:
         if collection.has_archive:
             self.route(cls=collection.archive)
 
-        for attr, attrval in get_subcollections(collection):
+        subcollections = get_subcollections(collection)
+
+        for attr, attrval in subcollections:
+            if attr not in self.subcollections.keys():
+                self.subcollections[attr] = [attrval]
+
+            else:
+                self.subcollections[attr].append(attrval)
+
             self.route(Collection.from_subcollection(
                     collection,
                     attr,
